@@ -21,5 +21,9 @@
 char *
 get_locale()
 {
-	return "jp";
+char * e_lang;
+	e_lang = getenv("LANG");
+	if ( e_lang == 0 )
+		return "en";
+	return get_abstract_locale(e_lang);
 }
