@@ -57,9 +57,9 @@ extern void v_loop();
 }
 
 VApplication *theApp = NULL;
-
-//#define CONSOLE_DEBUG
-
+/*
+#define CONSOLE_DEBUG
+*/
 static const WORD MAX_CONSOLE_LINES = 500;
 
 #ifdef CONSOLE_DEBUG
