@@ -33,6 +33,8 @@
 #include	"mx_format.h"
 #include	"win_flame.h"
 
+//#define DEBUG_RES_MATRIX
+
 #define SC_OFFSET	0
 #define SC_RATE		0.5
 #define KEY_LIMIT_RATE	0.8
@@ -302,8 +304,9 @@ int i;
 	err = load_matrix_header(m,O_RDWR,0644);
 	if ( err == 0 ) {
 
+#ifdef DEBUG_RES_MATRIX
 ss_printf("CALL insert_resource_matrix %ls %ls\n",filename,get_url_str2(&r->h.target));
-
+#endif
 		if ( m->p.flags & MPF_PERMISSION )
 			goto destroy_matrix;
 
@@ -393,6 +396,11 @@ insert_res_matrix_read_net(MATRIX_TOKEN * tk)
 RESOURCE * r;
 RES_MATRIX_T * t;
 
+#ifdef DEBUG_RES_MATRIX
+ss_printf("RESOURCE_MATRIX READ-NET %p %s\n",tk->process_node->matrix,pt_dc(tk->process_node->matrix,tk->process_node->dim_code,PTDC_NODE_ID));
+#endif
+
+
 	r = tk->process_node->matrix->open_work;
 	t = new_queue_node(sizeof(*t));
 	t->ret = 0;
@@ -481,7 +489,13 @@ int use;
 				0,0,0,0);
 		}
 		else {
+#ifdef DEBUG_RES_MATRIX
+ss_printf("RESOURCE_MATRIX BEFORE-START %p %s\n",t->token->process_node->matrix,pt_dc(t->token->process_node->matrix,t->token->process_node->dim_code,PTDC_NODE_ID));
+#endif
 			if ( t->aboat_flag ) {
+#ifdef DEBUG_RES_MATRIX
+ss_printf("RESOURCE_MATRIX BEFORE-AB %p %s\n",t->token->process_node->matrix,pt_dc(t->token->process_node->matrix,t->token->process_node->dim_code,PTDC_NODE_ID));
+#endif
 				t->token->work = 0;
 				matrix_token_error(t->token);
 				d_f_ree(t);
@@ -492,10 +506,9 @@ int use;
 			use = 1;
 			if ( (r->h.loop_no - t->token->process_node->process_token_key > spiral_count*SC_RATE + SC_OFFSET) ||
 				(lost_time == get_xltime() && lost_r == r) || (use=check_use_in_wf(r)) == 0 ) {
-/*
-ss_printf("ABORT %i %i %i - %i %i BEFORE\n",t->token->process_node->process_token_key,r->pr64.loop_no,spiral_count,
-res_matrix_before.total_cnt,res_matrix_after.total_cnt);
-*/
+#ifdef DEBUG_RES_MATRIX
+ss_printf("RESOURCE_MATRIX BEFORE-2 %p %s\n",t->token->process_node->matrix,pt_dc(t->token->process_node->matrix,t->token->process_node->dim_code,PTDC_NODE_ID));
+#endif
 				if ( use == 0 ) {
 					lost_r = r;
 					lost_time = get_xltime();
@@ -506,6 +519,9 @@ res_matrix_before.total_cnt,res_matrix_after.total_cnt);
 				gc_pop(0,0);
 				continue;
 			}
+#ifdef DEBUG_RES_MATRIX
+ss_printf("RESOURCE_MATRIX BEFORE-3 %p %s\n",t->token->process_node->matrix,pt_dc(t->token->process_node->matrix,t->token->process_node->dim_code,PTDC_NODE_ID));
+#endif
 			lost_r = 0;
 			sym = n_get_symbol("Get");
 			set_attribute(sym,l_string(std_cm,"mode"),l_string(std_cm,"data"));
@@ -516,9 +532,10 @@ res_matrix_before.total_cnt,res_matrix_after.total_cnt);
 						-1),
 					-1);
 			d_f_ree(f);
-/*
+
+#ifdef DEBUG_RES_MATRIX
 ss_printf("MATRIX DIMCODE=%s\n",pt_dc(t->token->process_node->matrix,t->token->process_node->dim_code,PTDC_PIXEL_1));
-*/
+#endif
 			t->ret = remote_session(gblisp_top_env0,ses,
 				&r->h.target,
 				0,
@@ -526,10 +543,12 @@ ss_printf("MATRIX DIMCODE=%s\n",pt_dc(t->token->process_node->matrix,t->token->p
 				l_string(std_cm,"Get"),
 				List(query,-1),
 				0,0,0,0);
-/*
-ss_printf("RESOURCE_MATRIX %i %i %i - %i %i BEFORE\n",t->token->process_node->process_token_key,r->h.loop_no,spiral_count,
-res_matrix_before.total_cnt,res_matrix_after.total_cnt);
-*/
+
+#ifdef DEBUG_RES_MATRIX
+ss_printf("RESOURCE_MATRIX %i %i %i - %i %i BEFORE %ls (%p %s)\n",t->token->process_node->process_token_key,r->h.loop_no,spiral_count,
+res_matrix_before.total_cnt,res_matrix_after.total_cnt,get_url_str2(&r->h.entry),t->token->process_node->matrix,
+pt_dc(t->token->process_node->matrix,t->token->process_node->dim_code,PTDC_NODE_ID));
+#endif
 		}
 		t->insert_time = get_xltime();
 		t->key_cnt = get_key_count(&res_matrix_after,key);
@@ -596,7 +615,9 @@ MATRIX_PARAM mp;
 				print_sexp(s_stdout,t->ret,0);
 				ss_printf("\n");
 				insert_lw_service_code_flag_set(t->r,t->ret);
+#ifdef DEBUG_RES_MATRIX
 ss_printf("FLAGS-3 = %p %x %x\n",t->r,t->r->h.flags,RF_REQUIRED_PERMISSION);
+#endif
 				goto err2;
 			}
 			cmd = get_el_by_symbol(t->ret,l_string(std_cm,"gmxStatus"),0);
@@ -625,13 +646,14 @@ ss_printf("FLAGS-3 = %p %x %x\n",t->r,t->r->h.flags,RF_REQUIRED_PERMISSION);
 				filename);
 			set_attribute(sym,l_string(std_cm,"activePhase_mode"),
 					l_string(std_cm,"client"));
-/*
+
+#ifdef DEBUG_RES_MATRIX
 ss_printf("CALL gmxCreate %ls %ls\n",filename,get_url_str2(&t->r->h.target));
 print_sexp(s_stdout,cmd,0);
 ss_printf("\n");
 
 ss_printf("CALL gmxCreate %ls %ls\n",filename,get_url_str2(&t->r->h.target));
-*/
+#endif
 			d_f_ree(filename);
 
 			memset(&cp,0,sizeof(cp));
@@ -671,8 +693,14 @@ ss_printf("CALL gmxCreate %ls %ls\n",filename,get_url_str2(&t->r->h.target));
 			unlock_task(res_lock,"matrix");
 		}
 		else {
+#ifdef DEBUG_RES_MATRIX
+ss_printf("RESOURCE_MATRIX AFTER-4 %p %s\n",t->token->process_node->matrix,pt_dc(t->token->process_node->matrix,t->token->process_node->dim_code,PTDC_NODE_ID));
+#endif
 			if ( t->aboat_flag )
 				goto err;
+#ifdef DEBUG_RES_MATRIX
+ss_printf("RESOURCE_MATRIX AFTER-5 %p %s\n",t->token->process_node->matrix,pt_dc(t->token->process_node->matrix,t->token->process_node->dim_code,PTDC_NODE_ID));
+#endif
 			if ( get_type(t->ret) == XLT_ERROR ) {
 				r = (RESOURCE*)t->token->process_node->matrix->open_work;
 				insert_lw_service_code_flag_set(r,t->ret);
@@ -686,9 +714,14 @@ ss_printf("CALL gmxCreate %ls %ls\n",filename,get_url_str2(&t->r->h.target));
 				goto err;
 			}
 			r = (RESOURCE*)t->token->process_node->matrix->open_work;
+#ifdef DEBUG_RES_MATRIX
+ss_printf("RESOURCE_MATRIX AFTER-6 %p %s\n",t->token->process_node->matrix,pt_dc(t->token->process_node->matrix,t->token->process_node->dim_code,PTDC_NODE_ID));
+#endif
 			if ( decode_matrix_node(t->token->process_node,t->ret) < 0 )
 				goto err;
-
+#ifdef DEBUG_RES_MATRIX
+ss_printf("RESOURCE_MATRIX AFTER-7 %p %s\n",t->token->process_node->matrix,pt_dc(t->token->process_node->matrix,t->token->process_node->dim_code,PTDC_NODE_ID));
+#endif
 			lock_task(res_lock);
 			if ( r->h.non_setup_vm )
 				r->h.non_setup_vm = setup_view_methods(r,t->token->process_node,
@@ -714,11 +747,11 @@ ss_printf("CALL gmxCreate %ls %ls\n",filename,get_url_str2(&t->r->h.target));
 			}
 
 			debug_target_matrix = t->token->process_node->matrix;
-/*
-ss_printf("RRR %i %f %i\n",tim,limit,res_matrix_before.key_limit);
+#ifdef DEBUG_RES_MATRIX
+ss_printf("RRR %i %f %i %s\n",tim,limit,res_matrix_before.key_limit,pt_dc(t->token->process_node->matrix,t->token->process_node->dim_code,PTDC_NODE_ID));
 ss_printf("RESOURCE_MATRIX %i %i %i - %i %i\n",t->token->process_node->process_token_key,r->h.loop_no,spiral_count,
 res_matrix_before.total_cnt,res_matrix_after.total_cnt);
-*/
+#endif
 			lock_task(res_matrix_lock);
 			t->token->work = 0;
 			t->token->aboat_func = 0;
