@@ -398,6 +398,7 @@ L_CHAR * filename;
 XL_SEXP * ret;
 U_STAT buf;
 STREAM * st;
+XL_SEXP * ld;
 
 CALL_LOCK_DESCRIPTER lr;
 
@@ -418,6 +419,7 @@ CALL_LOCK_DESCRIPTER lr;
 	}
 
 	ret = init_parse(st,filename,filename);
+	for ( ld = ret ; get_type(ld) == XLT_PAIR ; ld = cdr(ld) );
 
 	switch ( get_type(ret) ) {
 	case XLT_ERROR:
@@ -1025,7 +1027,7 @@ int sts;
 static int local_ip;
 unsigned int mod;
 int site;
-
+int er;
 	if ( local_ip == 0 )
 		local_ip = get_xllisp_site_ip().d.v4;
 
@@ -1037,7 +1039,9 @@ int site;
 		er_panic("get_mpi");
 	}
 	p = get_my_port();
-	get_url2(&u,url_str);
+	er = get_url2(&u,url_str);
+if ( er )
+ss_printf("get_mpi = %i\n",er);
 	lock_task(mpi_lock);
 	if ( u.proto == 0 )
 		u.proto = nl_copy_str(std_cm,"xlp");
