@@ -331,7 +331,7 @@ retry:
 		0600,PF_USEFREELIST,FT_RT_CACHE,0,0,0);
 	if ( rc_p ) {
 		fofs = 0;
-		h = get_file_record(&fofs,
+		h = l_get_file_record(&fofs,
 			rc_p,PNT_RT_CACHE_HEADER);
 		if ( h == 0 ) {
 			l_close_filespace(rc_p);
