@@ -1,6 +1,6 @@
 /**********************************************************************
  
-	Copyright (C) 2003 Hirohisa MORI <joshua@nichibun.ac.jp>
+	Copyright (C) 2003-2007 Hirohisa MORI <joshua@globalbase.org>
  
 	This program is free software; you can redistribute it 
 	and/or modify it under the terms of the GLOBALBASE 
@@ -552,7 +552,7 @@ printf("??????????????? insert_irq\n");
 	if ( gf )
 		gf->indicate_req ++;
 	ir->r = r;
-	ir->counter = r->draw_gb.loop_no;
+	ir->counter = r->h.loop_no;
 	sprintf(irq,"gf%x",(int)gf);
 	ir->h.key = nl_copy_str(std_cm,irq);
 	insert_queue(&r->draw_gb.ir_que,ir,0);
@@ -576,6 +576,8 @@ RESOURCE * r;
 OBJ * o;
 GBVIEW_FLAME * gf;
 	r = search_resource_by_no(rno);
+	if ( r->h.type != RT_DRAW_GB )
+		return;
 	if ( r->draw_gb.type == DGT_LOAD )
 		return;
 	ir = delete_queue(&r->draw_gb.ir_que,ir_cmp_code,&code,0);
@@ -669,6 +671,11 @@ XL_SEXP * s;
 		return;
 	case OF_INFO_PROC:
 		return;
+	case OF_INFO_UNSTYLED:
+		formating_info(r,o);
+		o->h.flags &= ~OF_INFO_STS;
+		o->h.flags |= OF_INFO_FETCH;
+		goto fetch;
 	case OF_INFO_FETCH:
 	fetch:
 		if ( o->h.info_org == 0 )
@@ -852,9 +859,9 @@ XL_SEXP * sym;
 		break;
 	case OF_INFO_XML:
 	case OF_INFO_NULL:
-		o->h.info_card = get_card_info(r,o->h.info_org);
+		o->h.info_card = get_card_info(r,r->draw_gb.ischeme,o->h.info_org);
 		o->h.info_onmap = get_onmap_info(
-			r,
+			r,r->draw_gb.ischeme,
 			o->h.info_org,
 			&o->h.onmap_resolution);
 		if ( get_type(o->h.info_onmap) == XLT_ERROR ) {
@@ -1103,14 +1110,13 @@ PRI_CTL_THREAD tt1;
 		o->h.flags &= ~OF_INFO_SCHEME;
 		o->h.flags |= flags&(~OF_INFO_STS);
 		o->h.info_org = info_org;
-		formating_info(r,o);
-		card_data = o->h.info_card;
+//		formating_info(r,o);
 
 		enter_pri_ctl(&parse_lock_ctl,&tt1);
 
 		wf_iom_lock();
 		o->h.flags &= ~OF_INFO_STS;
-		o->h.flags |= OF_INFO_FETCH;
+		o->h.flags |= OF_INFO_UNSTYLED;
 		if ( o->h.flags & OF_ONMAP_REQ ) {
 		GB_POINT ptr;
 			o->h.flags &= ~OF_ONMAP_REQ;
@@ -1122,8 +1128,13 @@ PRI_CTL_THREAD tt1;
 
 		exit_pri_ctl(&parse_lock_ctl);
 	}
-	if ( gf )
+	if ( gf ) {
+		formating_info(r,o);
+		card_data = o->h.info_card;
+		o->h.flags &= ~OF_INFO_STS;
+		o->h.flags |= OF_INFO_FETCH;
 		insert_indicate_info(gf,r,code,flags,card_data);
+	}
 /*
 	lock_task(indicate_lock);
 	ready_indicate();
@@ -1186,7 +1197,7 @@ CHECK_IRQ_T w;
 int wait_flag;
 
 	wf_lock(gf);
-	ZONBIE_CHECK(gf,wf_unlock,1)
+	ZONBIE_CHECK(gf,wf_unlock(gf),1)
 	wf_unlock(gf);
 	gc_push(0,0,"check_irq");
 	query = 0;
@@ -1205,7 +1216,7 @@ int wait_flag;
 		gf->indicate_req --;
 		wf_indicate_unlock(gf);
 
-		if ( ir2->counter <= r->draw_gb.loop_no - spiral_count -2 ) {
+		if ( ir2->counter <= r->h.loop_no - spiral_count -2 ) {
 			o = search_obj(r,ir2->code);
 			if ( o && (o->h.flags&OF_INFO_STS) ==
 					OF_INFO_PROC ) {
@@ -1306,8 +1317,10 @@ os_test2 = 0;
 /*
 	unlock_pdb_lock(r);
 */
-	if ( setup_ret )
+	if ( setup_ret ) {
+//		_wf_set_delay_redraw(gf);
 		_wf_set_redraw(gf);
+	}
 end:
 	gc_pop(0,0);
 	return er;
@@ -1384,6 +1397,7 @@ INDICATE_INFO_TASK_CHECK_T w;
 	close_self_interpreter();
 end:
 	release_qkey(que,key);
+	d_f_ree(key);
 }
 
 
