@@ -597,33 +597,51 @@ SURP_SET surp;
 int id;
 int ci_ret;
 
+
+	wf_lock(gf);
 	ci_ret = 0;
 	if ( r->tl.x < 0 ) {
-		if ( r->br.x <= 0 )
+		if ( r->br.x <= 0 ) {
+			wf_unlock(gf);
 			return -1;
+		}
 		r->tl.x = 0;
 	}
-	if ( r->tl.x >= gf->win_width )
+	if ( r->tl.x >= gf->win_width ) {
+		wf_unlock(gf);
 		return -1;
-	if ( r->br.x <= 0 )
+	}
+	if ( r->br.x <= 0 ) {
+		wf_unlock(gf);
 		return -1;
+	}
 	if ( r->br.x > gf->win_width ) {
-		if ( r->tl.x >= gf->win_width )
+		if ( r->tl.x >= gf->win_width ) {
+			wf_unlock(gf);
 			return -1;
+		}
 		r->br.x = gf->win_width;
 	}
 	if ( r->tl.y < 0 ) {
-		if ( r->br.y <= 0 )
+		if ( r->br.y <= 0 ) {
+			wf_unlock(gf);
 			return -1;
+		}
 		r->tl.y = 0;
 	}
-	if ( r->tl.y >= gf->win_height )
+	if ( r->tl.y >= gf->win_height ) {
+		wf_unlock(gf);
 		return -1;
-	if ( r->br.y <= 0 )
+	}
+	if ( r->br.y <= 0 ) {
+		wf_unlock(gf);
 		return -1;
+	}
 	if ( r->br.y > gf->win_height ) {
-		if ( r->tl.y >= gf->win_height )
+		if ( r->tl.y >= gf->win_height ) {
+			wf_unlock(gf);
 			return -1;
+		}
 		r->br.y = gf->win_height;
 	}
 	min_x = r->br.x;
@@ -632,8 +650,6 @@ int ci_ret;
 	max_y = r->tl.y;
 
 
-	wf_lock(gf);
-
 
 /*
 	if ( _check_exit_flame(gf) ) {
