@@ -45,6 +45,7 @@ new_win_flame(
 WIN_FLAME_TABLE * tbl;
 int ret;
 int pri;
+WIN_FLAME * wf;
 	pri = push_pri(PRI_DRAW);
 	wf_lock(gf);
 	ZONBIE_CHECK(gf,(wf_unlock(gf),change_pri(0,pri)),0)
@@ -73,12 +74,50 @@ int pri;
 			center,
 			rotate,
 			resolution);
+	if ( ret < 0 )
+		goto end;
+
+	wf_lock(gf);
+	wf = _get_wf_ptr(gf,*ret_wfid);
+	if ( wf == 0 ) {
+		wf_unlock(gf);
+		ret = -1;
+		goto end;
+	}
+	if ( wf->flags & (WFF_FREE|WFF_FREE_OUTLIST) ) {
+		wf_unlock(gf);
+		ret = -1;
+		goto end;
+	}
+	if ( _win_wlock(gf,wf) < 0 ) {
+		wf_unlock(gf);
+		ret = -1;
+		goto end;
+	}
+	wf_unlock(gf);
+
+	wf_check_small(gf,wf);
+	switch ( wf->flags&(WFF_TO_SMALL|WFF_TO_STD) ) {
+	case WFF_TO_SMALL:
+		change_win_flame(gf,wf,0,WFT_SMALL);
+		break;
+	case WFF_TO_STD:
+		change_win_flame(gf,wf,0,WFT_STD);
+		break;
+	case 0:
+		break;
+	default:
+		er_panic("change_task_gf");
+	}
+	
+	win_unlock(gf,wf);
+	
 	wf_lock(gf);
 	wf_unlock(gf);
 	wakeup_at_redraw_wp(gf);
 	call_flame_insert_event(gf);
 	wakeup_hwf(gf,HWFF_TYPE_TO_FRAME);
-	
+end:
 	change_pri(0,pri);
 	return ret;
 }
@@ -151,6 +190,7 @@ int ret;
 		return -1;
 	if ( wf->tbl->f_flame_redraw == 0 )
 		return 0;
+
 //	wf_set_delay_redraw_flag(gf,1);
 	ret = (*wf->tbl->f_flame_redraw)(gf,wf);
 //	wf_set_delay_redraw_flag(gf,0);
