@@ -18,6 +18,7 @@
 
 #include	"xlerror.h"
 #include	"xl.h"
+#include	"gbmp.h"
 
 
 XL_SEXP * xl_mp_Exit();
@@ -32,7 +33,11 @@ init_mp_Exit(XLISP_ENV * env)
 XL_SEXP *
 xl_mp_Exit(XLISP_ENV * env,XL_SEXP * s)
 {
+/*
+	wait_que_stable();
 	exit_stabilizer('e');
+*/
+	mp_live(1);
 	exit(0);
 }
 
