@@ -1479,7 +1479,7 @@ ss_printf("LCR 2\n");
 		}
 		target[i] = t0->id;
 	}
-	if ( search_ipt(_target,_e->pri,0,0) == 0 )
+	if ( _e && search_ipt(_target,_e->pri,0,0) == 0 )
 		new_loop_check(start_point,_e->pri,
 			_e->dir[0].hops+10,_target,1);
 	d_f_ree(_target);
