@@ -24,6 +24,10 @@ int exit_mode;
 
 XL_SEXP * genExit();
 
+
+int genExit_no;
+int genExit_tid;
+
 void
 init_genExit(XLISP_ENV * env)
 {
@@ -34,16 +38,29 @@ init_genExit(XLISP_ENV * env)
 XL_SEXP *
 genExit(XLISP_ENV * env,XL_SEXP * s)
 {
-int iid;
+//int iid;
+XL_SEXP * ret;
+
+genExit_no = 1;
+genExit_tid = get_tid();
+/*
   	iid = get_main_interpreter();
+genExit_no = 2;
+genExit_tid = get_tid();
 	if ( iid >= 0 )
 		close_interpreter(iid);
-	return get_error(
+genExit_no = 3;
+genExit_tid = get_tid();
+*/
+	ret = get_error(
 		s->h.file,
 		s->h.line,
 		XLE_SYSTEM_EXIT,
 		l_string(std_cm,"Exit"),
 		0);
+genExit_no = 4;
+genExit_tid = get_tid();
+	return ret;
 }
 
 
