@@ -24,8 +24,9 @@
 #include	"resource.h"
 #include	"lump.h"
 
-
-
+/*
+#define QUERY_DEBUG
+*/
 
 void
 set_metadata(L_CHAR * db,GB_RECT * minrect,REAL1 reso,
@@ -57,6 +58,18 @@ r->h.visible_resolution,
 n_string(std_cm,crd),
 n_string(std_cm,get_url_str2(&r->h.entry)));
 
+#ifdef QUERY_DEBUG
+ss_printf(
+"PMD_DB db = %s (%f %f)-(%f %f) %f %s %s\n",
+n_string(std_cm,db),
+r->h.minrect.tl.x,
+r->h.minrect.tl.y,
+r->h.minrect.br.x,
+r->h.minrect.br.y,
+r->h.visible_resolution,
+n_string(std_cm,crd),
+n_string(std_cm,get_url_str2(&r->h.entry)));
+#endif
 
 	err_pos = 0;
 	er = 0;
@@ -249,6 +262,16 @@ err3:
 				err_pos,
 				e_code,
 				e_favt_code);
+
+
+#ifdef QUERY_DEBUG
+ss_printf(
+	"PMD_DB UNLINK (%s) err_pos = %i (%i / %i)\n",
+	path,
+	err_pos,
+	e_code,
+	e_favt_code);
+#endif
 			u_unlink(path);
 			d_f_ree(path);
 		}
@@ -263,10 +286,18 @@ check_favt_ring();
 err0:
 	return;
 err4:
-	if ( err_pos || er )
+	if ( err_pos || er ) {
 		log_printf(LOG_MESSAGE,LOG_LAYER_GB,0,
-			"PMD_DB ERR (%s) err_pos = %i er = %i\n",
-			w.path,err_pos,er);
+			"PMD_DB ERR db=(%s) err_pos = %i er = %i\n",
+			db,err_pos,er);
+
+#ifdef QUERY_DEBUG
+ss_printf(
+	"PMD_DB ERR db=(%s) err_pos = %i er = %i\n",
+	db,err_pos,er);
+#endif
+
+	}
 	return;
 }
 
