@@ -181,14 +181,13 @@ typedef struct lc_string_pic {
 
 typedef struct lc_font_engine {
 	struct lc_font_engine *		next;
-	char *				name;
+	const char *			name;
 	struct lc_font_engine_type *	type;
 	void *				work;
 } LC_FONT_ENGINE;
 
 typedef struct lc_font_engine_type {
-//	char	type[32];
-	char *	type;
+	const char *	type;
 	int	(*fe_new)(LC_FONT *,LC_FONT_ENGINE *);
 	void	(*fe_get_pic)(
 			LC_STRING_PIC * sp,
@@ -325,7 +324,7 @@ L_CHAR * _l_string_1(CODE_METHOD *,char*);
 L_CHAR * _l_string_2(CODE_METHOD *,char*);
 
 #define l_string(cm,str)	\
-	((#str)[0] == '\"' ? _l_string_2(cm,str) : _l_string_1(cm,str))
+	((#str)[0] == '\"' ? _l_string_2(cm,(char*)str) : _l_string_1(cm,(char*)str))
 
 
 char * n_string(CODE_METHOD *,L_CHAR *);
@@ -577,7 +576,13 @@ FONT_PRI * cws_fitting_font_pri(LC_CWS * cws,L_CHAR lcz,int * fp_ws_count);
 void _lc_copy_ws_cond(LC_WS_COND * dest,LC_WS_COND * src);
 int col_code_entry(CODE_ENTRY * ce1,CODE_ENTRY * ce2);
 void marge_code_entry(CODE_ENTRY * e1,CODE_ENTRY * e2);
+
+LCZ_SET * get_hit_code(LCZ_SET * set,L_CHAR * str,int len);
+
 extern LCZ_SET major_code[];
+extern LCZ_SET lang_japanese[];
+extern LCZ_SET lang_chinese[];
+extern LCZ_SET lang_korean[];
 char * get_machine_filename_string(L_CHAR*);
 
 extern char * (*__get_machine_filename_string)(L_CHAR *);
