@@ -28,7 +28,7 @@
 
 
 #define GB_NAMESPACE	"xlp://isjhp1.nichibun.ac.jp:8080/gb_metadata"
-#define RADAR_CACHE_SIZE		100
+#define RADAR_CACHE_SIZE		500
 #define RADAR_MATRIX_CACHE_SIZE		100
 #define RADAR_RECT_RATE			10
 #define RADAR_DOTS			500
@@ -39,7 +39,7 @@
 #define RADAR_RESO_PTR_SIZE		8
 
 #define WIN_RESO_WINDOW_MIN		2
-#define WIN_RESO_WINDOW_MAX		8000
+#define WIN_RESO_WINDOW_MAX		800000
 
 #define GLOBE_RESO_LIMIT		800
 
@@ -93,6 +93,7 @@ typedef struct radar_lump {
 	float			recommend_interval;
 	int			q_len;
 	INTEGER64		invalid;
+	int			invalid_cnt;
 } RADAR_LUMP;
 
 typedef struct radar_node {
@@ -348,6 +349,7 @@ typedef struct radar_cache {
 
 	unsigned		win_remake:1;
 	unsigned		win_force:1;
+	int			change_condition_delete;
 
 
 	void 			(*indicate_event)(RADAR_INDICATE *,void*);
@@ -583,13 +585,13 @@ GB_RECT
 get_fitting_rect(int * fitting_p,GB_RECT * target,REAL1 reso,RADAR_CACHE * rc_ptr,
 			Q_THREAD_LIST * qt);
 void insert_radar_matrix(RADAR_CACHE * rc_ptr,int qt_id,RADAR_CRD * c,int lock_flag);
-void _free_node_from_matrix(RADAR_MATRIX * mx);
-void _free_node_from_matrix2(RADAR_MATRIX * mx);
+void _xx_free_node_from_matrix(RADAR_MATRIX * mx,char*,int);
+void _xx_free_node_from_matrix2(RADAR_MATRIX * mx,char*,int);
 void free_radar_matrix(RADAR_CACHE * rc_ptr,Q_THREAD_LIST * qt);
 void _clean_top_of_matrix(RADAR_CACHE * rc_ptr,Q_THREAD_LIST * qt);
-int __clean_radar_matrix(RADAR_CACHE * rc_ptr,Q_THREAD_LIST * qt,RADAR_MATRIX * mx);
-void _clean_force_matrix(RADAR_CACHE * rc_ptr,int clear_count);
-void clean_radar_matrix(RADAR_CACHE * rc_ptr,Q_THREAD_LIST * qt);
+int __xx_clean_radar_matrix(RADAR_CACHE * rc_ptr,Q_THREAD_LIST * qt,RADAR_MATRIX * mx,char*,int);
+void _xx_clean_force_matrix(RADAR_CACHE * rc_ptr,int clear_count,char*,int);
+void xx_clean_radar_matrix(RADAR_CACHE * rc_ptr,Q_THREAD_LIST * qt,char*,int);
 int set_ptr_list(RADAR_CACHE * rc_ptr,int ses,RADAR_CRD * c);
 int _insert_radar_url(RADAR_CACHE * rc_ptr,int qt_id,int ses,L_CHAR * crd,L_CHAR * obj,int wup_flag);
 int remake_cache(RADAR_CACHE * rc_ptr,int ses,int type,WF_ID current,WF_ID next);
@@ -611,7 +613,7 @@ void dump_the_matrix_qt(RADAR_CACHE * rc_ptr,Q_THREAD_LIST * qt,GB_RECT * r,int
 void dump_the_matrix(RADAR_CACHE * rc_ptr,GB_RECT * r);
 WF_ID win_manage(RADAR_CACHE * rc_ptr,WF_ID * next,int ses,REAL1 reso,GB_RECT * r);
 int in_condition(RADAR_CACHE * rc_ptr,GB_RECT * r,REAL1 window,REAL1 max);
-void _empty_radar_matrix(RADAR_MATRIX * mx,int fn_flag);
+void _xx_empty_radar_matrix(RADAR_MATRIX * mx,int fn_flag,char*,int);
 void query_trigger(RADAR_CACHE * rc_ptr,int fn_flag);
 void _query_trigger2(RADAR_CACHE * rc_ptr);
 void query_trigger2(RADAR_CACHE * rc_ptr);
@@ -723,11 +725,11 @@ XL_SEXP * q_thread_to_sexp_1(QUERY_THREAD * qt,int mode);
 
 RADAR_MATRIX_LIST *
 _get_radar_matrix_all(RADAR_CACHE * rc_ptr,REAL1 reso,GB_RECT * r,int insert_flag);
-void _free_radar_matrix_all(RADAR_CACHE * rc_ptr);
-void free_radar_matrix_all(RADAR_CACHE * rc_ptr);
+void _xx_free_radar_matrix_all(RADAR_CACHE * rc_ptr,char*,int);
+void xx_free_radar_matrix_all(RADAR_CACHE * rc_ptr,char*,int);
 int _cmp_q_thread(QUERY_THREAD * q1,QUERY_THREAD * q2,int flag);
 REAL1 _get_qt_min_reso(RADAR_CACHE * rc_ptr);
-void _empty_radar_matrix_in_query(RADAR_CACHE * rc_ptr,int fn_flag);
+void _xx_empty_radar_matrix_in_query(RADAR_CACHE * rc_ptr,int fn_flag,char*,int);
 int _rc_insert_q_thread(
 	RADAR_CACHE * rc_ptr,
 	QUERY_THREAD * q_list);
