@@ -46,6 +46,7 @@ extern "C" {
 #define XLIE_CANNOT_OPEN_BUSY	(-6)
 #define XLIE_CANNOT_OPEN_DENIED	(-7)
 #define XLIE_CANNOT_OPEN_SERVICE_INVALID (-8)
+#define XLIE_CANNOT_OPEN_TTL	(-9)
 
 /* xl accept type */
 #define XLA_STDIO	1
@@ -229,8 +230,9 @@ typedef struct xl_interpreter {
 #define XIF_BREAK	0x00000001
 #define XIF_CANCEL	0x00000002
 #define XIF_TERMINAL	0x00010000
-#define XIF_ASYNC	0x00020000
-#define XIF_PERMISSION	0x00040000
+#define XIF_CATCH	0x00020000
+#define XIF_ASYNC	0x00040000
+#define XIF_PERMISSION	0x00080000
 #define XIF_P_MASK	0x00700000
 #define XIF_P_ALLOW	0x00100000
 #define XIF_P_DENIED	0x00200000
@@ -1007,6 +1009,10 @@ void init_xl_ri();
 extern XL_SEXP * (*convert_code_ptr)(XL_SEXP * st,LCZ_SET * set,int flags);
 void
 set_arg(int _argc,char ** _argv,int v_offset);
+int
+set_xli_flags(int iid,int flags,int mask);
+XL_SEXP *
+xli_break_check(XL_SEXP * s,int timing);
 
 
 #ifdef __cplusplus
