@@ -77,13 +77,13 @@ XL_SEXP * gb_let(XLISP_ENV *,XL_SEXP *);
 XL_SEXP * get_symbol(L_CHAR*);
 void set_attribute(XL_SEXP *,L_CHAR *,L_CHAR *);
 XL_SEXP * replace_attribute(XL_SEXP *,L_CHAR * ,L_CHAR * );
-XL_SEXP * n_get_symbol(char *);
+XL_SEXP * n_get_symbol(const char *);
 XL_SEXP * get_string(L_CHAR*);
-XL_SEXP * n_get_string(char*);
+XL_SEXP * n_get_string(const char*);
 XL_SEXP * get_integer(INTEGER64,L_CHAR*);
-XL_SEXP * n_get_integer(int,char*);
+XL_SEXP * n_get_integer(int,const char*);
 XL_SEXP * get_floating(double,L_CHAR*);
-XL_SEXP * n_get_floating(double,char*);
+XL_SEXP * n_get_floating(double,const char*);
 XL_SEXP * get_raw(char * data,int size);
 XL_SEXP * get_raw_set_data(char * data,int size);
 XL_SEXP * get_error(
@@ -186,7 +186,7 @@ extern XLISP_ENV *	gblisp_top_env1;
 extern XL_FILE * std_file;
 extern XL_SEXP * (*break_check)();
 
-void gc_push(void * s,void (*gc)(),char * msg);
+void gc_push(void * s,void (*gc)(),const char * msg);
 void gc_pop(void * s,void (*gc)());
 
 STREAM * get_sexp_stream(XL_SEXP *);
