@@ -713,8 +713,14 @@ LC_WS_COND wsc;
 		wsc.cond = WSC_PIC_REQUIRED;
 		set = ws_convert(el->d.ws.ws,&wsc,el->d.ws.size,&el->ch,1,
 				CBF_SRC_PLANE|CBF_DST_PLANE);
-		if ( set == 0 || set->font == 0 )
-			er_panic("put_char");
+		if ( set == 0 || set->font == 0 ) {
+		L_CHAR question;
+			question = '?';
+			set = ws_convert(el->d.ws.ws,&wsc,el->d.ws.size,&question,1,
+					CBF_SRC_PLANE|CBF_DST_PLANE);
+			if ( set->font == 0 || set->size == 0 )
+				er_panic("char");
+		}
 		if ( set->font != ew->font )
 			goto new_el;
 		if ( set->size != ew->size )
