@@ -69,7 +69,6 @@ FAVT64_NODE *
 large_node64(int * errp,FAVT64_ROOT * rt,FAVT64_NODE * n);
 void
 favt64_valance(int * errp,FAVT64_ROOT * p,FAVT64_PTR * favtp);
-void free_bound_list64(BOUND64_LIST * b);
 void favt64_alloc_header(PDB64 * p,FAVT64_HEADER * ret,PN64_HEADER * h);
 void cc_node64(char * str,FAVT64_NODE * n);
 void cc_root64(char * str,FAVT64_ROOT * r);
@@ -170,6 +169,7 @@ insert_favt64_ring(FAVT64_HEADER * h)
 	h->next = favt64_h.next;
 	h->prev->next = h;
 	h->next->prev = h;
+	h->access_time = get_xltime();
 	favt64_count ++;
 }
 
@@ -428,6 +428,8 @@ clear_cache64()
 FAVT64_NODE * n;
 FAVT64_ROOT * r;
 FAVT64_HEADER * h, * h2;
+INTEGER64 now;
+	now = get_xltime();
 	for ( ; favt64_count > FAVT64_CACHE_SIZE ; ) {
 		for ( h = favt64_h.prev ; h != &favt64_h ; ) {
 			if ( h->flags & FAF_LOCK ) {
@@ -456,10 +458,14 @@ FAVT64_HEADER * h, * h2;
 			default:
 				er_panic("clear_cache");
 			}
+			if ( now - h->access_time < FAVT64_CACHE_LIFE ) {
+				h = h->prev;
+				continue;
+			}
 			break;
 		}
 		if ( h == &favt64_h )
-			er_panic("clear_cache");
+			break;
 		if ( check_dirty64(h,0) ) {
 			for ( h2 = favt64_h.next ; h2 != &favt64_h ; 
 					h2 = h2->next )
@@ -981,6 +987,63 @@ BOUND64_SEARCH_WORK w;
 	return w.head;
 }
 
+
+int
+_favt64_bound_search_reverse(
+	int * errp,
+	BOUND64_SEARCH_WORK * w,
+	FAVT64_NODE * a)
+{
+int cmp_max,cmp_min;
+	touch_ring64(w->p,a);
+	if ( a == 0 )
+		return 0;
+	favt64_lock(&a->h);
+	cmp_max = (*w->cmp)(a->data,w->data_max,w->cmp_work);
+	cmp_min = (*w->cmp)(a->data,w->data_min,w->cmp_work);
+	if ( cmp_max < 0 ) {
+		if( _favt64_bound_search(errp,w,
+				large_node64(errp,w->p,a)) < 0 )
+			return -1;
+	}
+	if ( cmp_max <= 0 && cmp_min >= 0 ) {
+		if ( insert_lst64(errp,w,a) < 0 )
+			return -1;
+	}
+	if ( cmp_min > 0 ) {
+		if ( _favt64_bound_search(errp,w,
+				small_node64(errp,w->p,a)) < 0 )
+			return -1;
+	}
+	favt64_unlock(&a->h);
+	return 0;
+}
+
+BOUND64_LIST *
+favt64_bound_search_reverse(
+	int * errp,
+	FAVT64_ROOT * p,
+	FAVT64_NODE * a,
+	void *	data_min,
+	void *	data_max,
+	int	limit,
+	int (*cmp)(),
+	void * cw)
+{
+BOUND64_SEARCH_WORK w;
+	w.p = p;
+	w.data_min = data_min;
+	w.data_max = data_max;
+	w.head = w.tail = 0;
+	w.cmp = cmp;
+	w.cmp_work = cw;
+	w.limit = limit;
+	w.count = 0;
+	_favt64_bound_search_reverse(errp,&w,a);
+	return w.head;
+}
+
+
 void
 free_bound_list64(BOUND64_LIST * b)
 {
