@@ -838,15 +838,15 @@ MX_CACHE_PARAM p;
 	size_ix = mxc_alloc(&read_c,sizeof(int)*(mtx->p.dim));
 	inc = mxc_alloc(&read_c,sizeof(int)*(mtx->p.dim));
 	for ( i = 0 ; i < m->p.dim ; i ++ ) {
-		target[i+1] = target[i+1] & (-(1<<(target[0]*m->dim_divide[i] + 
+		target[i+1] = target[i+1] & (-(((INTEGER64)1)<<(target[0]*m->dim_divide[i] + 
 						m->block_size[i])));
 		target_ix[i] = 0;
 		start_ix[i] = 0;
 		inc[i] = 1;
 		if ( (target[i+1]>>(target[0]*m->dim_divide[i])) + 
-				(1<<m->block_size[i])
+				(((INTEGER64)1)<<m->block_size[i])
 				<= m->pixel_size_list[target[0]][i] )
-			size_ix[i] = (1<<mtx->block_size[i])+hem;
+			size_ix[i] = (((INTEGER64)1)<<mtx->block_size[i])+hem;
 		else	size_ix[i] =
 			m->pixel_size_list[target[0]][i] - 
 			(target[i+1]>>(target[0]*m->dim_divide[i])) + hem;
@@ -1013,9 +1013,9 @@ MX_CACHE_PARAM p;
 		start_ix[i] = 0;
 		inc[i] = 1;
 		if ( (dc[i+1]>>(dc[0]*m->dim_divide[i])) + 
-				(1<<m->block_size[i])
+				(((INTEGER64)1)<<m->block_size[i])
 				<= m->pixel_size_list[dc[0]][i] )
-			size_ix[i] = 1<<mtx->block_size[i];
+			size_ix[i] = ((INTEGER64)1)<<mtx->block_size[i];
 		else	size_ix[i] =
 			m->pixel_size_list[dc[0]][i] - 
 			(dc[i+1]>>(dc[0]*m->dim_divide[i]));
@@ -1988,7 +1988,7 @@ ss_printf("pee-ph-1.1\n");
 	for ( i = 1 ; i <= mtx->p.dim ; i ++ ) {
 		target_ix[i] = dc[i];
 		inc[i] = 1;
-		_len = (1<<m->block_size[i-1]);
+		_len = (((int)1)<<m->block_size[i-1]);
 		end_pos[i] = dc[i] + _len;
 		if ( end_pos[i] > m->pixel_size[i-1] ) {
 			end_pos[i] = m->pixel_size[i-1];
@@ -2948,7 +2948,7 @@ retry:
 	p = get_matrix_node_channel(
 		&err,&n,m,dim_code,
 		CH_PARAM_DOUBLE,GN_NODE,GN_NODE_CREATE,
-		&vp);
+		&vp,0);
 	if ( p == 0 ) {
 		if ( err == ME_MATRIX_ERR ) {
 			sleep_sec(1);
@@ -2975,7 +2975,7 @@ retry:
 	p = get_matrix_node_channel(
 		&err,&n,m,dim_code,
 		CH_PARAM_DOUBLE,GN_NODE,GN_NODE_CREATE,
-		&vp);
+		&vp,0);
 	if ( p == 0 ) {
 		fprintf(stderr,"cannot write parameters (%i)\n",err);
 		exit(1);
@@ -3063,6 +3063,8 @@ double zero = 0;
 
 	minimum_matrix_init(argc,argv); 
 
+	tick_start_unlock();
+
 	for ( inp = 1 ; inp < argc && 
 		strcmp(argv[inp],"-inp") ; inp ++ );
 	if ( inp == argc ) {
