@@ -1341,9 +1341,9 @@ V_CALLBACK_D(VgbWPMenuEdit::__set_iwp)
 VgbWPMenuEdit * obj;
 VMenuItem * item;
 	item = static_cast<VMenuItem*>(user_arg);
-	VCustomizedMenuBar::menu_lock_inheritance(item->i_tid,__FILE__,__LINE__);
+	VCustomizedMenuBar::menu_lock_inheritance(item->i_tid,(char*)__FILE__,__LINE__);
 	obj = (VgbWPMenuEdit*)item->get_user_work();
-	VCustomizedMenuBar::menu_unlock(__FILE__,__LINE__);
+	VCustomizedMenuBar::menu_unlock((char*)__FILE__,__LINE__);
 	obj->_set_iwp();
 }
 
@@ -1416,7 +1416,7 @@ int len;
 	memset(e,0,sizeof(*e));
 	e->submenu_type = WPM_ST_NORMAL;
 	if ( wpm_w.sts.untitled == 0 )
-		e->name = nl_copy_str(std_cm,"Untitled");
+		e->name = nl_copy_str(std_cm,(char*)"Untitled");
 	else	e->name = ll_copy_str(wpm_w.sts.untitled);
 	
 	bcl = wpm_w.xltv_obj->get_selected_bc_list(GST_LIST,&len);
@@ -1431,10 +1431,10 @@ VgbWPMenuEdit * obj;
 VMenuItem * item;
 ss_printf("warp_point_callback_add_group\n");
 	item = static_cast<VMenuItem*>(user_arg);
-	VCustomizedMenuBar::menu_lock_inheritance(item->i_tid,__FILE__,__LINE__);
+	VCustomizedMenuBar::menu_lock_inheritance(item->i_tid,(char*)__FILE__,__LINE__);
 	obj = (VgbWPMenuEdit*)item->get_user_work();
 	obj->__wpe_new_group();
-	VCustomizedMenuBar::menu_unlock(__FILE__,__LINE__);
+	VCustomizedMenuBar::menu_unlock((char*)__FILE__,__LINE__);
 }
 
 void
@@ -1499,9 +1499,9 @@ VgbWPMenuEdit * obj;
 VMenuItem * item;
 ss_printf("warp_point_callback_save_as\n");
 	item = static_cast<VMenuItem*>(user_arg);
-	VCustomizedMenuBar::menu_lock_inheritance(item->i_tid,__FILE__,__LINE__);
+	VCustomizedMenuBar::menu_lock_inheritance(item->i_tid,(char*)__FILE__,__LINE__);
 	obj = (VgbWPMenuEdit*)item->get_user_work();
-	VCustomizedMenuBar::menu_unlock(__FILE__,__LINE__);
+	VCustomizedMenuBar::menu_unlock((char*)__FILE__,__LINE__);
 	obj->_wpe_save_as();
 }
 
@@ -1539,9 +1539,9 @@ V_CALLBACK_D(VgbWPMenuEdit::_wpe_open)
 VgbWPMenuEdit * obj;
 VMenuItem * item;
 	item = static_cast<VMenuItem*>(user_arg);
-	VCustomizedMenuBar::menu_lock_inheritance(item->i_tid,__FILE__,__LINE__);
+	VCustomizedMenuBar::menu_lock_inheritance(item->i_tid,(char*)__FILE__,__LINE__);
 	obj = (VgbWPMenuEdit*)item->get_user_work();
-	VCustomizedMenuBar::menu_unlock(__FILE__,__LINE__);
+	VCustomizedMenuBar::menu_unlock((char*)__FILE__,__LINE__);
 	obj->_wpe_open();
 }
 
@@ -1566,9 +1566,9 @@ V_CALLBACK_D(VgbWPMenuEdit::_wpe_new)
 VgbWPMenuEdit * obj;
 VMenuItem * item;
 	item = static_cast<VMenuItem*>(user_arg);
-	VCustomizedMenuBar::menu_lock_inheritance(item->i_tid,__FILE__,__LINE__);
+	VCustomizedMenuBar::menu_lock_inheritance(item->i_tid,(char*)__FILE__,__LINE__);
 	obj = (VgbWPMenuEdit*)item->get_user_work();
-	VCustomizedMenuBar::menu_unlock(__FILE__,__LINE__);
+	VCustomizedMenuBar::menu_unlock((char*)__FILE__,__LINE__);
 	obj->_wpe_new();
 }
 
@@ -1667,9 +1667,9 @@ VgbWPMenuEdit * obj;
 VMenuItem * item;
 ss_printf("warp_point_callback_save\n");
 	item = static_cast<VMenuItem*>(user_arg);
-	VCustomizedMenuBar::menu_lock_inheritance(item->i_tid,__FILE__,__LINE__);
+	VCustomizedMenuBar::menu_lock_inheritance(item->i_tid,(char*)__FILE__,__LINE__);
 	obj = (VgbWPMenuEdit*)item->get_user_work();
-	VCustomizedMenuBar::menu_unlock(__FILE__,__LINE__);
+	VCustomizedMenuBar::menu_unlock((char*)__FILE__,__LINE__);
 	obj->__wpe_save();
 }
 
@@ -1960,7 +1960,7 @@ VxlEditLineStatus e_sts;
 	v_sts.parent = base;
 	v_sts.visible = 1;
 	if ( e->wpm == 0 )
-		v_sts.descriptor = nl_copy_str(std_cm,"---");
+		v_sts.descriptor = nl_copy_str(std_cm,(char*)"---");
 	else	v_sts.descriptor = ll_copy_str(e->wpm->name);
 
 	e->main_bc = static_cast<VBackColorView*>(
@@ -2714,7 +2714,7 @@ _LOAD_BUTTON_T * t;
 		_lb_tail = t;
 	}
 	else	_lb_head = _lb_tail = t;
-	load_meta_2("data",t->target,_load_button,(void*)t,0);
+	load_meta_2((char*)"data",t->target,_load_button,(void*)t,0);
 	
 	_load_button(0,e->submenu);
 }
