@@ -48,11 +48,12 @@ char * menu_unlock_file;
 int inheritance_id;
 
 extern "C" {
-void (*ms_lock_func)(char *,int);
+int (*ms_lock_func)(int,char *,int);
 void (*ms_unlock_func)();
 void (*ms_inheritance_func)(int,char*,int);
 
 int inheritance_mode;
+int lthread_agent_tid,intermediate_thread_id;
 }
 
 
@@ -447,7 +448,7 @@ V_CALLBACK_D(VMenuBar::refresh_menu_bar)
 int category;
 	if ( window_list == 0 )
 		return;
-	VCustomizedMenuBar::menu_lock((char*)__FILE__,__LINE__);
+	VCustomizedMenuBar::menu_lock(1,(char*)__FILE__,__LINE__);
 	category = (int)user_arg;
 	window_list->refresh_menu_bar(category);
 	VCustomizedMenuBar::menu_unlock((char*)__FILE__,__LINE__);
@@ -571,7 +572,7 @@ V_CALLBACK_D(VCustomizedMenuBar::set_menu_flag_que)
 SET_MENU_T * sm;
 VCustomizedMenuBar * mb;
 	sm = (SET_MENU_T*)user_arg;
-	menu_lock((char*)__FILE__,__LINE__);
+	menu_lock(1,(char*)__FILE__,__LINE__);
 	mb = sm->win->get_menu_bar();
 	if ( mb )
 		mb->set_menu_flag(sm->id,sm->flag);
@@ -595,7 +596,7 @@ V_CALLBACK_D(VCustomizedMenuBar::set_menu_func_que)
 SET_MENU_T * sm;
 VCustomizedMenuBar * mb;
 	sm = (SET_MENU_T*)user_arg;
-	menu_lock((char*)__FILE__,__LINE__);
+	menu_lock(1,(char*)__FILE__,__LINE__);
 	mb = sm->win->get_menu_bar();
 	if ( mb )
 		mb->set_menu_func(sm->id,sm->func,sm->data);
@@ -620,7 +621,7 @@ V_CALLBACK_D(VCustomizedMenuBar::set_menu_name_que)
 SET_MENU_T * sm;
 VCustomizedMenuBar * mb;
 	sm = (SET_MENU_T*)user_arg;
-	menu_lock((char*)__FILE__,__LINE__);
+	menu_lock(1,(char*)__FILE__,__LINE__);
 	mb = sm->win->get_menu_bar();
 	if ( mb )
 		mb->set_menu_name(sm->id,sm->name);
@@ -683,21 +684,33 @@ VCustomizedMenuBar::init_menu_lock()
 }
 
 
-void 
-VCustomizedMenuBar::menu_lock(char * file,int line) {
+int
+VCustomizedMenuBar::menu_lock(int wait_flag,char * file,int line) {
 int tid;
+int ret;
+	ret = 0;
 	lock_task(_menu_lock);
 	for ( ; inheritance_mode ; ) {
 		sleep_task((int)&inheritance_mode,_menu_lock);
 		lock_task(_menu_lock);
+		ret = 0;
 	}
 	if ( ms_lock_func ) {
 		unlock_task(_menu_lock,"menu_lock");
-		(*ms_lock_func)(file,line);
+		ret = (*ms_lock_func)(wait_flag,file,line);
 	}
 	else {
 		tid = get_tid();
 		if ( menu_lock_tid && menu_lock_tid != tid ) {
+			if ( lthread_agent_tid == tid && menu_lock_tid == intermediate_thread_id ) {
+				menu_lock_cnt ++;
+				goto ok;
+			}
+			if ( wait_flag == 0 ) {
+				ret = -1;
+				unlock_task(_menu_lock,"menu_lock");
+				goto end;
+			}
 			for ( ; menu_lock_cnt != 0 ; ) {
 				sleep_task((int)&_menu_lock,_menu_lock);
 				lock_task(_menu_lock);
@@ -707,11 +720,14 @@ int tid;
 		menu_lock_tid = tid;
 		menu_lock_file = file;
 		menu_lock_line = line;
+	ok:
 		unlock_task(_menu_lock,"menu_lock");
 	}
 /*
 printf("menu_lock %s %i\n",file,line);
 */
+end:
+	return ret;
 }
 
 void 
@@ -724,8 +740,12 @@ int tid;
 	}
 	else {
 		tid = get_tid();
-		if  ( menu_lock_tid != tid )
+		if  ( menu_lock_tid != tid ) {
+			if ( lthread_agent_tid == tid && menu_lock_tid == intermediate_thread_id )
+				goto ok;
 			er_panic("menu_unlock(1)");
+		}
+	ok:
 		menu_lock_cnt --;
 		if ( menu_lock_cnt == 0 ) {
 			wakeup_task((int)&_menu_lock);
