@@ -29,6 +29,7 @@
 #include	"pri_level.h"
 #include	"lc_encode.h"
 #include	"XLoHTTP.h"
+#include	"progressive.h"
 
 void gc_tick_notin_tick();
 
@@ -91,6 +92,8 @@ int dque_task_point;
 int (* agent_open_xli)();
 int (* agent_close_xli)();
 
+int all_xli_flags;
+
 
 PRI_CTL xli_lock_ctl = {PRI_NETWORK,0,0};
 
@@ -133,6 +136,8 @@ int i;
 	printf(" \n");
 }
 
+void
+init_stream_routing(XLISP_ENV * env);
 
 void
 _close_all_interpreter();
@@ -146,6 +151,7 @@ void xli_tick();
 
 XL_SEXP * _xli_break_check();
 int xl_int_handler();
+int (*xl_int_handler_backup)();
 char site_name[100];
 void delay_thread();
 
@@ -248,6 +254,8 @@ init_interpreter()
 //	new_tick(xli_tick,20,0);
 
 	break_check = _xli_break_check;
+	
+	xl_int_handler_backup = int_handler;
 	int_handler = xl_int_handler;
 /*
 	get_localhostname(site_name);
@@ -260,6 +268,8 @@ init_interpreter()
 	init_http_agent(); 
 
 	init_authentificaition(gblisp_top_env0);
+	init_progressive(gblisp_top_env0);
+	init_stream_routing(gblisp_top_env1);
 }
 
 void
@@ -653,8 +663,15 @@ PERMISSION_LIST *
 check_permission_list(XL_INTERPRETER * xli,int ip)
 {
 PERMISSION_LIST * pl;
+ACCESS_LIST * al;
+HOST_ADDR_EXT dest;
 	for ( pl = xli->pl_head ; pl ; pl = pl->next ) {
-		if ( check_permission(&pl->ap,ip,0) == AP_DENY )
+		dest.type = HAT_XLPROX_V4;
+		dest.am.addr.d.xp_v4.v4 = ip;
+		dest.am.addr.d.xp_v4.id = -1;
+		dest.am.addr.port = -1;
+		al = check_permission(&pl->ap,0,&dest);
+		if ( al == 0 || al->type == AP_DENY )
 			continue;
 		return pl;
 	}
@@ -822,7 +839,7 @@ int pri;
 			l_string(std_cm,"break"),
 			0);
 	}
-	if ( xli->flags & XIF_BREAK ) {
+	else if ( xli->flags & XIF_BREAK ) {
 		ret = get_error(
 			s->h.file,
 			s->h.line,
@@ -844,6 +861,44 @@ end:
 	return ret;
 }
 
+XL_SEXP *
+xli_break_check(XL_SEXP * s,int timing)
+{
+static int tm;
+	tm ++;
+	if ( timing < timing ) {
+		return 0;
+	}
+	if ( break_check == 0 ) 
+		return 0;
+	return (*break_check)(s);
+}
+
+int
+set_xli_flags(int iid,int flags,int mask)
+{
+XL_INTERPRETER * xli;
+int ret;
+	lock_task(xli_lock);
+	if ( iid < 0 ) {
+		ret = all_xli_flags;
+		all_xli_flags &= ~mask;
+		all_xli_flags |= flags;
+	}
+	else {
+		xli = _get_my_xli();
+		if ( xli == 0 ) {
+			er_panic("push_xli_flags");
+		}
+		ret = xli->flags;
+		xli->flags &= ~mask;
+		xli->flags |= flags&mask;
+	}
+	unlock_task(xli_lock,"push_xli_flags");
+	return ret;
+}
+
+
 XL_INTERPRETER *
 _search_xli_id(unsigned int id)
 {
@@ -1352,6 +1407,10 @@ retry:
 	return;
 }
 
+
+int close_interpreter_no;
+int close_interpreter_tid;
+
 int
 _close_interpreter(XL_INTERPRETER * xli)
 {
@@ -1359,9 +1418,14 @@ XL_RESULT * resp;
 int id;
 int er;
 
+close_interpreter_tid = get_tid();
+close_interpreter_no = 1;
+
 	if( xli->mode == XIM_CLOSE )
 		return -1;
 	if ( xli->result_head ) {
+close_interpreter_tid = get_tid();
+close_interpreter_no = 2;
 		id = xli->id;
 		unlock_task(xli_lock,"_close_interpreter");
 		gc_tick_notin_tick(0,0);
@@ -1372,9 +1436,13 @@ int er;
 		if ( xli->mode == XIM_CLOSE )
 			return -1;
 	}
+close_interpreter_tid = get_tid();
+close_interpreter_no = 3;
 	xli->flags |= XIF_BREAK;
 	for ( resp = xli->result_list ; resp ;
 			resp = resp->my_xli_result_next ) {
+close_interpreter_tid = get_tid();
+close_interpreter_no = 4;
 		if ( resp->out_interpreter == 0 )
 			continue;
 
@@ -1389,14 +1457,20 @@ int er;
 			s_close_queue(resp->out_interpreter->out);
 			resp->out_interpreter->out = 0;
 		}
+close_interpreter_tid = get_tid();
+close_interpreter_no = 5;
 	}
 
+close_interpreter_tid = get_tid();
+close_interpreter_no = 6;
 	s_close_queue(xli->inp);
 	if ( xli->inp == xli->out )
 		xli->out = 0;
 	if ( xli->inp == xli->err )
 		xli->err = 0;
 	xli->inp = 0;
+close_interpreter_tid = get_tid();
+close_interpreter_no = 7;
 	return 0;
 }
 
@@ -1405,22 +1479,32 @@ close_interpreter(int id)
 {
 XL_INTERPRETER * xli;
 	lock_task(xli_lock);
+close_interpreter_tid = get_tid();
+close_interpreter_no = 8;
 	xli = _search_xli_id(id);
 	if ( xli == 0 ) {
 		unlock_task(xli_lock,"close_interpreter");
 		goto end;
 	}
+close_interpreter_tid = get_tid();
+close_interpreter_no = 9;
 	if ( _close_interpreter(xli) == 0 ) {
 		xli = _search_xli_id(id);
 		if ( xli == 0 ) {
 			unlock_task(xli_lock,"close_interpreter");
 			goto end;
 		}
+close_interpreter_tid = get_tid();
+close_interpreter_no = 10;
 		sleep_task((int)xli,xli_lock);
 	}
 	else
 		unlock_task(xli_lock,"close_interpreter");
+close_interpreter_tid = get_tid();
+close_interpreter_no = 11;
 end:
+close_interpreter_tid = get_tid();
+close_interpreter_no = 12;
 	{}
 }
 void
@@ -1614,7 +1698,6 @@ printf("BUSY 1\n");
 			d_f_ree(key);
 			continue;
 		}
-
 		pl = check_permission_list(xli,key->ip);
 
 		if ( pl == 0 ) {
@@ -1626,7 +1709,6 @@ printf("BUSY 1\n");
 			continue;
 		}
 
-
 		invoke_time = get_xltime();
 		new_tick((void(*)(int))accept_thread_tick,
 			 -xli->accept_interval,(int)key->s);
@@ -2528,6 +2610,7 @@ SERVER_INFO si;
 }
 
 
+
 void
 _tick_check(XL_INTERPRETER * xli)
 {
@@ -2654,18 +2737,24 @@ xl_int_handler()
 {
 XL_INTERPRETER * xli;
 int i;
+int ret;
+
+
+	ret = -1;
+
+	if ( xl_int_handler_backup )
+		ret = (*xl_int_handler_backup)();
 
 	lock_task(xli_lock);
 	for ( i = 0 ; i < INTERPRETER_HASH_SIZE ; i ++ )
 		for ( xli = interpreter_hash[i] ; xli ;
 				xli = xli->next )
-			if (xli->flags & XIF_TERMINAL ) {
+			if ( (xli->flags & XIF_CATCH) || (all_xli_flags& XIF_CATCH) ) {
 				xli->flags |= XIF_CANCEL;
-				unlock_task(xli_lock,"xl_int_handler");
-				return 0;
+				ret = 0;
 			}
 	unlock_task(xli_lock,"xl_int_handler");
-	return -1;
+	return ret;
 }
 
 
