@@ -423,7 +423,7 @@ loop:
 		ret = get_el(resp->ret,2);
 		if ( get_type(ret) == XLT_ERROR ){
 			ret = get_error(
-				resp->file,
+				ret->h.file,
 				resp->line,
 				ret->err.code,
 				l_string(std_cm,"remote call"),
@@ -612,7 +612,7 @@ err:
 }
 
 XL_SEXP *
-local_query(XLISP_ENV * env,L_CHAR * cmd_str,XL_SEXP * cmd_sexp)
+local_query(XLISP_ENV * env,XL_INTERPRETER * _xli,L_CHAR * cmd_str,XL_SEXP * cmd_sexp)
 {
 XL_INTERPRETER * xli;
 XL_SEXP * ret;
@@ -625,7 +625,9 @@ int pri;
 	pri = push_pri_pctl(&xli_lock_ctl);
 
 	lock_task(xli_lock);
-	xli = _get_my_xli();
+	if ( _xli == 0 )
+		xli = _get_my_xli();
+	else	xli = _xli;
 	if ( xli == 0 )
 		er_panic("local_query");
 	if ( xli->mode != XIM_RUN ) {
