@@ -25,4 +25,7 @@ foreach a (packages/*/*)
 	cp ../../../../../../../../doc/install/READMEs/www-gateway/* .
 end
 
+rm packages/skeleton/old/main.html
+cp -rf except/skeleton.old.main.html packages/skeleton/old/main.html
+
 popd
